@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Dict, List, Union
 
 from botocore.response import StreamingBody
 
@@ -207,7 +207,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
